# chiral-client-python: Python client for Chiral Computing Cloud API

# Versions
- 0.2.1: ReCGen for virtual molecular library; Large language model LLama2 from Meta; 
- 0.1.0: gromacs

# Installation
`conda install -c conda-forge grpcio protobuf`
